Welcome to Track Analyzer’s documentation! — Track Analyzer 0.1a documentation

# Welcome to Track Analyzer’s documentation!

Track Analyzer is Python-based data visualization pipeline for tracking data. It does not perform any tracking, but takes as input any kind of tracked data. It analyzes trajectories by computing standard parameters such as velocity, acceleration, diffusion coefficient, divergence and curl maps, etc. This pipeline also offers a trajectory visualization in 2D (and soon in 3D rendering), using a selection tool allowing to perform some fate mapping and back-tracking. Track Analyzer can be run by means of a Jupyter notebook based graphical interface, so no programming knowledge is required.

## User Guide

- User Guide
  - Running Track Analyzer
  - Frequently Asked Questions

# Indices and tables

- Index

- Module Index

- Search Page